@@ -7,7 +7,6 @@ from fa.jquery.fanstatic_resources import fa_js
 
 fa_bootstrap_library = Library('fa_bootstrap', 'static')
 listing = Resource(fa_bootstrap_library, 'js/listing.js', depends=[jquery])
-alerts = Resource(fa_bootstrap_library, 'js/alerts.js', depends=[jquery])
 autocomplete = Resource(fa_bootstrap_library, 'js/autocomplete.js', depends=[jqueryui, fa_js])
 
-bootstrap = Group([listing, alerts, bootstrap, tablesorter])
+bootstrap = Group([listing, bootstrap, tablesorter])
